@@ -35,7 +35,7 @@ from ._types import (
 )
 
 
-__version__ = "2.0.5"
+__version__ = "2.0.6"
 _user_agent = " ".join(("scrapelib", __version__, requests.utils.default_user_agent()))
 
 
@@ -102,11 +102,11 @@ class RetrySession(requests.Session):
         files: Optional[MutableMapping[Text, IO[Any]]] = None,
         auth: _AuthType = None,
         timeout: Union[None, float, Tuple[float, float], Tuple[float, None]] = None,
-        allow_redirects: Optional[bool] = None,
+        allow_redirects: Optional[bool] = True,
         proxies: Optional[MutableMapping[Text, Text]] = None,
         hooks: Optional[_HooksInput] = None,
         stream: Optional[bool] = None,
-        verify: Union[None, bool, Text] = None,
+        verify: Union[None, bool, Text] = True,
         cert: Union[Text, Tuple[Text, Text], None] = None,
         json: Optional[Any] = None,
         retry_on_404: bool = False,
@@ -218,11 +218,11 @@ class ThrottledSession(RetrySession):
         files: Optional[MutableMapping[Text, IO[Any]]] = None,
         auth: _AuthType = None,
         timeout: Union[None, float, Tuple[float, float], Tuple[float, None]] = None,
-        allow_redirects: Optional[bool] = None,
+        allow_redirects: Optional[bool] = True,
         proxies: Optional[MutableMapping[Text, Text]] = None,
         hooks: Optional[_HooksInput] = None,
         stream: Optional[bool] = None,
-        verify: Union[None, bool, Text] = None,
+        verify: Union[None, bool, Text] = True,
         cert: Union[Text, Tuple[Text, Text], None] = None,
         json: Optional[Any] = None,
         retry_on_404: bool = False,
@@ -345,11 +345,11 @@ class CachingSession(ThrottledSession):
         files: Optional[MutableMapping[Text, IO[Any]]] = None,
         auth: _AuthType = None,
         timeout: Union[None, float, Tuple[float, float], Tuple[float, None]] = None,
-        allow_redirects: Optional[bool] = None,
+        allow_redirects: Optional[bool] = True,
         proxies: Optional[MutableMapping[Text, Text]] = None,
         hooks: Optional[_HooksInput] = None,
         stream: Optional[bool] = None,
-        verify: Union[None, bool, Text] = None,
+        verify: Union[None, bool, Text] = True,
         cert: Union[Text, Tuple[Text, Text], None] = None,
         json: Optional[Any] = None,
         retry_on_404: bool = False,
@@ -523,11 +523,11 @@ class Scraper(CachingSession):
         files: Optional[MutableMapping[Text, IO[Any]]] = None,
         auth: _AuthType = None,
         timeout: Union[None, float, Tuple[float, float], Tuple[float, None]] = None,
-        allow_redirects: Optional[bool] = None,
+        allow_redirects: Optional[bool] = True,
         proxies: Optional[MutableMapping[Text, Text]] = None,
         hooks: Optional[_HooksInput] = None,
         stream: Optional[bool] = None,
-        verify: Union[None, bool, Text] = None,
+        verify: Union[None, bool, Text] = True,
         cert: Union[Text, Tuple[Text, Text], None] = None,
         json: Optional[Any] = None,
         retry_on_404: bool = False,
